#! /usr/bin/env node
const program = require('commander')
const minimist = require('minimist')
const chalk = require('chalk')

program
  .version(require('../package.json').version, '-v, --version')
  .usage('<command> [options]')


// upgrade
program
  .command('upgrade')
  .description('Check the hzzt-cli version.')
  .action(() => {
    require('../lib/update')()
  })

// generate page
program
  .command('g <name>')
  .description('Generate template')
  .option('-t, --temp <name>', 'Auto generate <name> page', 'list')
  .option('-f --force', 'Overwrite target directory if it exists')
  .action((name, options) => {
    // console.log(options)
    if (minimist(process.argv.slice(3))._.length > 1) {
      console.log(chalk.yellow('\n Info: You provided more than one argument. The first one will be used as the app\'s name, the rest are ignored.'))
    } else {
      require('../lib/generate')(name, options)
    }
  })

program
	.command('m <template> <url>')
	.description("Set the template url.")
	.action((template, url) => {
		require('../lib/config').setUrl(template, url)
	})

program
	.command('config')
	.description("see the current config.")
	.action((template, mirror) => {
		require('../lib/config').getJson(template, mirror)
	})

program.on('--help', () => {
  console.log()
  console.log(`  Run ${chalk.cyan(`hzzt <command> --help`)} for detailed usage of given command.`)
  console.log()
})

program.commands.forEach(c => c.on('--help', () => console.log()))

program.parse(process.argv)
